@@ -1,15 +1,17 @@
 package Lingua::Stem::Ru;
-$Lingua::Stem::Ru::VERSION = '0.04_02'; # TRIAL
-
-$Lingua::Stem::Ru::VERSION = '0.0402';use 5.006;
+$Lingua::Stem::Ru::VERSION = '0.03';
+use 5.006;
 use strict;
 use warnings;
-use Exporter 5.57 'import';
+use Exporter;
 use Carp;
-
-our @EXPORT      = ();
-our @EXPORT_OK   = qw (stem stem_word clear_stem_cache stem_caching);
-our %EXPORT_TAGS = ();
+use vars qw (@ISA @EXPORT_OK @EXPORT %EXPORT_TAGS);
+BEGIN {
+    @ISA         = qw (Exporter);
+    @EXPORT      = ();
+    @EXPORT_OK   = qw (stem stem_word clear_stem_cache stem_caching);
+    %EXPORT_TAGS = ();
+}
 
 my $Stem_Caching  = 0;
 my $Stem_Cache    = {};
@@ -213,28 +215,23 @@ Clears the cache of stemmed words
 
 None by default.
 
+=head1 HISTORY
+
+=over 8
+
+=item *
+
+0.01 (2004-05-21)
+
+=back
+
 =head1 AUTHOR
 
 Aleksandr Guidrevitch <pillgrim@mail.ru>
 
-=head1 REPOSITORY
-
-L<https://github.com/neilb/Lingua-Stem-Ru>
-
 =head1 SEE ALSO
 
-=over
-
-=item L<Lingua::Stem> 
-
-provides an interface for some other pure Perl stemmers available
-on CPAN, including L<Lingua::Stem::Ru>
-
-=item L<Lingua::Stem::Snowball>
-
-=item L<Lingua::Stem::Any>
-
-=back
+ Lingua::Stem
 
 =head1 COPYRIGHT AND LICENSE
 
